summaryrefslogtreecommitdiffstats
path: root/src/H5Fprivate.h
diff options
context:
space:
mode:
authorSongyu Lu <songyulu@hdfgroup.org>2019-04-09 21:20:19 (GMT)
committerSongyu Lu <songyulu@hdfgroup.org>2019-04-09 21:20:19 (GMT)
commit477dda3c0daea39cdf409684e7dad0fd9367dd45 (patch)
tree08f8d1653aec4e356fb069ae3a7d8768009901e2 /src/H5Fprivate.h
parentd8ff8da46cb49098c41b421427967eb736e15236 (diff)
downloadhdf5-477dda3c0daea39cdf409684e7dad0fd9367dd45.zip
hdf5-477dda3c0daea39cdf409684e7dad0fd9367dd45.tar.gz
hdf5-477dda3c0daea39cdf409684e7dad0fd9367dd45.tar.bz2
HDFFV-10658 - setting and getting properties in API context:
1. switched to use the existing H5F_prefix_open_t for enum type; 2. put the common private function used by external.c and external_env.c into external_common.c
Diffstat (limited to 'src/H5Fprivate.h')
-rw-r--r--src/H5Fprivate.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/src/H5Fprivate.h b/src/H5Fprivate.h
index e3860a0..553e16b 100644
--- a/src/H5Fprivate.h
+++ b/src/H5Fprivate.h
@@ -702,8 +702,11 @@ typedef enum H5F_mem_page_t {
/* Type of prefix for opening prefixed files */
typedef enum H5F_prefix_open_t {
- H5F_PREFIX_VDS, /* Virtual dataset prefix */
- H5F_PREFIX_ELINK /* External link prefix */
+ H5D_PREFIX_ERROR = -1, /* Error */
+ H5F_PREFIX_VDS = 0, /* Virtual dataset prefix */
+ H5F_PREFIX_ELINK = 1, /* External link prefix */
+ H5F_PREFIX_EFILE = 2, /* External file prefix */
+ H5F_PREFIX_NONE = 3 /* Must be the last */
} H5F_prefix_open_t;